Building the documentation
==========================

User documentation of ``otupy``
code can be generated by running the following command in the root tree:

.. code-block::	python3

   pdoc src/otupy/ -o docs/code/

To view the documentation, open the ```docs/code/index.html``` in your
browser.
